@@ -2,7 +2,6 @@ import logging
 
 import monasca_setup.agent_config
 import monasca_setup.detection
-from monasca_setup.detection.utils import find_process_name
 
 log = logging.getLogger(__name__)
 
@@ -24,7 +23,7 @@ class MySQL(monasca_setup.detection.Plugin):
         """Run detection, set self.available True if the service is detected.
 
         """
-        if find_process_name('mysqld') is not None:
+        if monasca_setup.detection.find_process_name('mysqld') is not None:
             self.available = True
 
     def build_config(self):
@@ -33,14 +32,14 @@ class MySQL(monasca_setup.detection.Plugin):
         """
         config = monasca_setup.agent_config.Plugins()
         # First watch the process
-        config.merge(monasca_setup.detection.watch_process(['mysqld'], 'mysql'))
+        config.merge(monasca_setup.detection.watch_process(['mysqld']))
         log.info("\tWatching the mysqld process.")
 
         # Attempt login, requires either an empty root password from localhost
         # or relying on a configured /root/.my.cnf
         if self.dependencies_installed():  # ensures MySQLdb is available
-            import _mysql_exceptions
             import MySQLdb
+            import _mysql_exceptions
             try:
                 MySQLdb.connect(read_default_file=mysql_conf)
             except _mysql_exceptions.MySQLError:
@@ -58,8 +57,6 @@ class MySQL(monasca_setup.detection.Plugin):
                 try:
                     with open(mysql_conf, "r") as confFile:
                         for row in confFile:
-                            # If there are any spaces in confFile, remove them
-                            row = row.replace(" ", "")
                             if client_section:
                                 if "[" in row:
                                     break
